
.. automodule:: bci_framework.framework.editor.highlighters
   :members:
   :no-undoc-members:
   :no-show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   bci_framework.framework.editor.highlighters.css_syntax
   bci_framework.framework.editor.highlighters.python_syntax
